"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.bridge = void 0;
const generic_pool_1 = __importDefault(require("generic-pool"));
const bridge = (postgres, poolConfiguration) => {
    const pool = generic_pool_1.default.createPool({
        create: async () => {
            var _a, _b;
            return postgres({
                database: poolConfiguration.database,
                host: (_a = poolConfiguration.host) !== null && _a !== void 0 ? _a : 'localhost',
                idle_timeout: poolConfiguration.idleTimeoutMillis ? poolConfiguration.idleTimeoutMillis / 1000 : 0,
                max: 1,
                password: poolConfiguration.password,
                port: (_b = poolConfiguration.port) !== null && _b !== void 0 ? _b : 5432,
                ssl: poolConfiguration.ssl,
                username: poolConfiguration.user,
            });
        },
        destroy: (client) => {
            return client.end({
                timeout: 5,
            });
        },
    }, {
        max: poolConfiguration.max,
        min: poolConfiguration.min,
    });
    return {
        connect: async () => {
            const connection = await pool.acquire();
            return {
                query: async (sql) => {
                    // https://github.com/porsager/postgres#result-array
                    const resultArray = await connection.unsafe(sql);
                    return {
                        command: resultArray.command,
                        fields: resultArray.columns.map((column) => {
                            return {
                                dataTypeID: column.type,
                                name: column.name,
                            };
                        }),
                        rowCount: resultArray.count,
                        rows: Array.from(resultArray),
                    };
                },
            };
        },
    };
};
exports.bridge = bridge;
